<?php

namespace Drupal\languagewire_translation_provider\Database;

use Drupal\languagewire_translation_provider\Client\ConfigurationItemInterface;
use Drupal\languagewire_translation_provider\Platform\AllLanguages;
use Drupal\languagewire_translation_provider\Platform\AvailableServices;
use Drupal\languagewire_translation_provider\Platform\MachineTranslationLanguages;
use Drupal\languagewire_translation_provider\Platform\Services\DemoTranslation;
use Drupal\languagewire_translation_provider\Platform\Services\HumanAssistedMachineTranslation;
use Drupal\languagewire_translation_provider\Platform\Services\HumanTranslation;
use Drupal\languagewire_translation_provider\Platform\Services\MachineTranslation;

/**
 * Service Repository.
 */
final class TypedServiceRepository extends TypedConfigurationItemRepositoryBase implements ServiceRepositoryInterface {
  private const TYPE = 'service';

  /**
   * {@inheritDoc}
   */
  protected function type(): string {
    return self::TYPE;
  }

  /**
   * {@inheritDoc}
   */
  protected function map(\stdClass $service): ConfigurationItemInterface {
    switch ($service->item_id) {
      case AvailableServices::DEMO_SERVICE_ID:
        return new DemoTranslation(new AllLanguages());

      case AvailableServices::MACHINE_TRANSLATION_SERVICE_ID:
        return new MachineTranslation($service->item_id, $service->name, new MachineTranslationLanguages());

      case AvailableServices::POST_EDITED_MACHINE_TRANSLATION_SERVICE_ID:
      case AvailableServices::POST_EDITED_MACHINE_TRANSLATION_WITH_VALIDATION_SERVICE_ID:
        return new HumanAssistedMachineTranslation($service->item_id, $service->name, new MachineTranslationLanguages());

      default:
        return new HumanTranslation($service->item_id, $service->name, new AllLanguages());
    }
  }

}
